# Rich tables

* [Album](#album)
* [Calendar](#calendar)
* [Emails](#emails)
* [Hue](#hue)
* [Nested json](#nested_json)
* [Pr](#pr)
* [Simple json](#simple_json)
* [Tasks](#tasks)
* [Timed](#timed)


## Album
![image](svgs/album.svg)
## Calendar
![image](svgs/calendar.svg)
## Emails
![image](svgs/emails.svg)
## Hue
![image](svgs/hue.svg)
## Nested json
![image](svgs/nested_json.svg)
## Pr
![image](svgs/pr.svg)
## Simple json
![image](svgs/simple_json.svg)
## Tasks
![image](svgs/tasks.svg)
## Timed
![image](svgs/timed.svg)
